@@ -2,6 +2,10 @@ import json
 import websockets
 import asyncio
 import time
+import logging
+import random
+
+logging.getLogger(__name__)
 
 
 async def connection_manager(socket, timeout=5000):
@@ -21,8 +25,10 @@ async def connection_manager(socket, timeout=5000):
             try:
                 evt = await asyncio.wait_for(socket.recv(), timeout=timeout)
             except asyncio.TimeoutError:
+                logging.debug(f"No message in {timeout} seconds")
                 await _send_ping(socket)
             except asyncio.CancelledError:
+                logging.debug("Cancelled error thrown")
                 await _send_ping(socket)
             else:
                 # Handle any data manipulations that need to occur
